@@ -3,7 +3,7 @@ import os
 import sys
 import time
 from functools import cache
-from typing import Any, Optional
+from typing import Any
 
 from . import (getAllFileList, getFileBaseName, getPath, hold, makeFolder,
                readFile, remove, writeFile)
@@ -14,7 +14,7 @@ from .print import (BACKGROUND_DARKGREEN, BACKGROUND_DARKPINK,
                     FOREGROUND_BLACK, FOREGROUND_DARKRED, FOREGROUND_WHITE,
                     resetPrintColor, setPrintColor)
 
-TaskDataType = tuple[str, Optional[dict[str, Any]]]
+TaskDataType = tuple[str, dict[str, Any] | None]
 
 _workspacePath: str = ""
 
@@ -45,6 +45,7 @@ def runTask(moduleName: str, **parDict: Any):
     if hasattr(module, "clean"):
         module.clean()
 
+
 @cache
 def isTaskByDev():
     return sys.executable.endswith("python.exe")
